#!/bin/bash
#
# Extending SCOP sequences with PSI-BLAST searches on a database.
#
# This shell script grabs all FASTA files in a directory and starts
# a perl script which extends each sequence with PSI-BLAST searches.
#
# Each SCOP FASTA file should be in the form
#
# pos-train.SCOP.fasta
#
# where SCOP is a SCOP family name like a.26.1.1
#
# e.g. pos-train.a.26.1.1.fasta
#
# For a remote homology experiment each file holds all sequences from
# a superfamily without the given family like a.26.1.1. The a.26.1.1 sequences
# are in the pos-test.SCOP.fasta file for testing for remote homology.
#
# The first parameter of the script is the directory of the FASTA files.
#
# It's possible to start several runs in parallel on multi-core multi-processor
# systems. For every run a slot number should be given as a parameter
#
# e.g.
#
# sh sh/extend.sh /dirto/fastafiles 1
#
# The extended sequences are stored in the EXTENDED directory
#
# The extended sequences of one FASTA file are filtered out of duplicates.
#
# Note:
# The original sequences are added to the extended sequences.
#

#
# Martin Heusel
# Institute of Bioinformatics
# Johannes Kepler University Linz
# Austria
# http://www.bioinf.jku.at/
#
# v 1.0 30.07.2008
#
# $Id: extendSCOP.sh 48 2008-08-05 10:50:53Z mhe $
#

if [ $# -ne 2 ]; then  # We need parameters
  echo "usage: $0 dirtofastafiles slotnumber"
  exit -1
fi

datadir=$1

slot=$2

if [ ! -d $datadir ]; then
    echo "FASTA directory does not exist!"
    echo "usage: $0 dirtofastafiles slotnumber"
    exit -1
fi

for fasta in $datadir/pos-train.*.fasta; do
    tmp=${fasta#$datadir/pos-train.}
    sccs=${tmp%.fasta}
    echo $sccs
    if [ -e OUT/$slot/blast-1.out ]; then
        rm OUT$slot/*.out
    fi
    if [ ! -e EXTENDED/$sccs.fasta ]; then
        touch EXTENDED/$sccs.fasta
        perl perl/search.pl $fasta tmp$slot.fasta $slot
        cd OUT$slot
        for i in blast-*.out; do
            perl ../perl/extractAlignmentsFromBlastout.pl $i >> ../EXTENDED/$sccs.fasta
        done
        cd ../EXTENDED
        cat ../$fasta >> $sccs.fasta
        # remove duplicates
        perl ../perl/findDupSeqs.pl $sccs.fasta > tmp.$sccs.fasta
        mv tmp.$sccs.fasta $sccs.fasta
        cd ..
        rm OUT$slot/*.out
    fi
done
